==> hyper-materialshell-1.4.0.tgz: package/README.md <==
# hyper-materialshell

[![Build Status](https://img.shields.io/travis/carloscuesta/hyper-materialshell.svg?style=flat-square)](https://travis-ci.org/carloscuesta/hyper-materialshell)
[![npm Downloads](https://img.shields.io/npm/dt/hyperterm-materialshell.svg?style=flat-square)](https://www.npmjs.com/package/hyperterm-materialshell)
[![XO code style](https://img.shields.io/badge/code_style-XO-5ed9c7.svg?style=flat-square)](https://github.com/sindresorhus/xo)
[![GitHub license](https://img.shields.io/github/license/carloscuesta/hyper-materialshell.svg?style=flat-square)](https://github.com/carloscuesta/hyper-materialshell/blob/master/LICENSE)

![hyper](https://cloud.githubusercontent.com/assets/7629661/17600203/b890114c-6002-11e6-87ab-e07f911e4568.png)

> A material design theme for [Hyper](http://hyper.is) based on [Carlos Cuesta's materialshell](https://github.com/carloscuesta/materialshell).

### Install

1. Open Hyper.app preferences with your editor - Tip: `CMD+,` or at `~/.hyper.js`.
2. Add `hyper-materialshell` to your plugins list.
3. Reload hyper - `CMD+Shift+R`.

```js
plugins: ['hyper-materialshell']
```

### Customization

Materialshell also has an Oceanic colorscheme, to use this version, edit `.hyper.js` and add this code inside of the `config: {}` object.

```javascript
materialshell: {
  theme: 'oceanic'
}
```

### FAQ

**What font is that?**

[Consolas](https://en.wikipedia.org/wiki/Consolas) a monospaced typeface.

**How can I get the cool prompt?**

The prompt isn't part of Hyper or iTerm, it has to do with the shell. I'm using ZSH with along with [materialshell](https://github.com/carloscuesta/materialshell) take a look at the materialshell repository.

**Can I make contributions?**

Yes! You can submit an issue and send a pull request :tada:

### You might also like

[materialshell ZSH prompt](https://github.com/carloscuesta/materialshell#shell-prompt)

[materialshell for iTerm](https://github.com/carloscuesta/materialshell#iterm)

[materialshell for Cmder](https://github.com/carloscuesta/materialshell#cmder)

==> hyper-materialshell-1.5.0.tgz: package/README.md <==
# hyper-materialshell

[![Build Status](https://img.shields.io/travis/carloscuesta/hyper-materialshell.svg?style=flat-square)](https://travis-ci.org/carloscuesta/hyper-materialshell)
[![npm downloads](https://img.shields.io/npm/dt/hyper-materialshell.svg?style=flat-square)](http://npmjs.com/carloscuesta/hyper-materialshell)
[![XO code style](https://img.shields.io/badge/code_style-XO-5ed9c7.svg?style=flat-square)](https://github.com/sindresorhus/xo)
[![GitHub license](https://img.shields.io/github/license/carloscuesta/hyper-materialshell.svg?style=flat-square)](https://github.com/carloscuesta/hyper-materialshell/blob/master/LICENSE)

![hyper](https://cloud.githubusercontent.com/assets/7629661/17600203/b890114c-6002-11e6-87ab-e07f911e4568.png)

> A material design theme for [Hyper](http://hyper.is) based on [Carlos Cuesta's materialshell](https://github.com/carloscuesta/materialshell).

## Install

1. Open Hyper.app preferences with your editor - Tip: `CMD+,` or at `~/.hyper.js`.
2. Add `hyper-materialshell` to your plugins list.
3. Reload hyper - `CMD+Shift+R`.

```js
plugins: ['hyper-materialshell']
```

## Customization

Materialshell also has an Oceanic colorscheme, to use this version, edit `.hyper.js` and add this code inside of the `config: {}` object.

```javascript
materialshell: {
  theme: 'oceanic'
}
```

## FAQ

**What font is that?**

[Consolas](https://en.wikipedia.org/wiki/Consolas) a monospaced typeface.

**How can I get the cool prompt?**

The prompt isn't part of Hyper or iTerm, it has to do with the shell. I'm using ZSH with along with [materialshell](https://github.com/carloscuesta/materialshell) take a look at the materialshell repository.

## You might also like

[ZSH materialshell prompt](https://github.com/carloscuesta/materialshell#shell-prompt)

[iTerm materialshell](https://github.com/carloscuesta/materialshell#iterm)

[Atom material syntax](https://github.com/carloscuesta/material-syntax)
